Metropolis-Hastings Green Reversible Jump move, with Bayesian Borrowing
.J_RJMCMC(
df_hist,
df_curr,
Y,
Y_0,
I,
I_0,
X,
X_0,
lambda,
lambda_0,
beta,
beta_0,
mu,
sigma2,
tau,
s,
J,
Jmax,
bp,
bp_0,
clam_smooth,
a_tau = NULL,
b_tau = NULL,
c_tau = NULL,
d_tau = NULL,
type,
p_0 = NULL,
phi,
pi_b,
maxSj
)list of proposed J and s, with adjusted values of lambda, lambda_0, tau, Sigma_s, and data_frames for historical and current trial data.
data_frame containing historical data.
data_frame containing current trial data.
data.
historical data.
censoring indicator.
historical trial censoring indicator.
design matrix.
historical trial design matrix.
baseline hazard.
historical trial baseline hazard.
current trial parameters.
historical trial parameters.
prior mean for baseline hazard.
prior variance hyperparameter for baseline hazard.
borrowing parameter.
split point locations, J + 2.
number of split points.
maximum number of split points.
number of covariates in current trial.
number of covariates in historical trial.
neighbor interactions, in range (0, 1), for ICAR update.
tau hyperparameter.
tau hyperparameter.
tau hyperparameter.
tau hyperparameter.
choice of borrowing, "mix", "uni", or any other string for borrowing on every baseline hazard without mixture.
mixture ratio.
J hyperparameter.
probability of birth move.
maximal time point, either current or historic.