Learn R Programming

BayesFBHborrow (version 2.0.2)

.beta_mom.NR.fun: First and second derivative of target for mode and variance of proposal

Description

First and second derivative of target for mode and variance of proposal

Usage

.beta_mom.NR.fun(df, k, beta, bp, cprop_beta)

Value

First and second derivative mode and variance

Arguments

df

Data frame with indicators

k

index

beta

vector of parameters

bp

number of covariates

cprop_beta

proposal variance standard deviation