.birth_move: Birth move in RJMCMC
Description
Calculates new values of x when proposing another split point, based on a
weighted mean, as x_new/x <- (1-U)/U
Usage
.birth_move(U, sj, s_star, sjm1, x, j)
Value
vector with adjusted parameter values after additional split point,
length J + 2
Arguments
- U
uniform random number
- sj
upcoming split point location, j
- s_star
new split point location, *
- sjm1
previous split point location, j-1
- x
vector of parameter values, length J + 1
- j
split point