.death_move: Death move in RJMCMC
Description
Calculates new values of x when proposing the death of a split point
Usage
.death_move(sjp1, sj, sjm1, x, j)
Value
vector with adjusted parameter values after removal of split point,
length J
Arguments
- sjp1
upcoming split point location, J + 1
- sj
split point location to be removed, j
- sjm1
previous split point location, j-1
- x
vector of parameter values, length J + 1
- j
split point