Learn R Programming

BayesFBHborrow (version 2.0.2)

.normalize_prob: Normalize a set of probability to one, using the the log-sum-exp trick

Description

Normalize a set of probability to one, using the the log-sum-exp trick

Usage

.normalize_prob(x)

Value

normalized set of log probabilities

Arguments

x

set of log probabilities