set.seed(111)
# Load example data and set your initial values and hyper parameters
data(weibull_cc, package = "BayesFBHborrow")
data(weibull_hist, package = "BayesFBHborrow")
Y <- weibull_cc$tte
I <- weibull_cc$event
X <- weibull_cc$X_trt
# Say we want to know the group level data for the following split points
s <- quantile(Y, c(0, 0.45, 0.65, 1), names = FALSE)
group_summary(Y, I, X, s)
Run the code above in your browser using DataLab